#!/bin/bash

#
# Script to merge and update the existing custom and
# saved databses with the new default.
#

tmpdir="/tmp/db_merge/"
defaultdb="/etc/logicube/cdb/default.db"
saveddb="/home/logicube/cdb/saved.db"
initialdb="/home/logicube/cdb/custom/initial.db"
activedb="/home/logicube/cdb/active.db"
mergesql="/etc/logicube/cdb/merge.sql"
logfile="/tmp/db_merge.log"
customdbs="/home/logicube/cdb/custom/*"

rm -rf $tmpdir
mkdir -p $tmpdir

# Create a copy of the new default database and merge
# the rows from an existing database.
merge_db()
{
	db=$1
	dbdir=`dirname "$db"`
	dbname=`basename "$db"`
	sqlname="$tmpdir/${dbname}.sql"
	sedopt="2s/XXXX/$dbname/"

	echo "Executing merge for: $dbdir/$dbname"
	cd $dbdir
	# Create a copy of the new default database for 
	# replacing the existing one
	cp -a $defaultdb "${dbname}.dflt"
	# Create the sql script using template.
	sed "$sedopt" $mergesql > "$sqlname"
	# Perform the merge
	cat "$sqlname" | sqlite3 "${dbname}.dflt"
}

# Replace the database using the newly create replacment
update_db()
{
	db=$1
	dbdir=`dirname "$db"`
	dbname=`basename "$db"`
	ndbname="${dbname}.dflt"

	echo "Executing update for: $dbdir/$dbname"
	cd $dbdir
	mv "$ndbname" "$dbname"
}

# Do the merge fnd replace or all the existing 
# custom databses
for db in $customdbs; do
	if [ -e ${db} ]; then
		merge_db "$db"
		update_db "$db"
	fi
done

# overwrite default database as initial db
cp -av $initialdb  ${initialdb}.bkp
cp -av $defaultdb $initialdb 

# restore the language keys
rows=`sqlite3 ${initialdb}.bkp "select * from system_cfg;" | grep "lang-key"`
for row in $rows
do
    lang=`echo $row | cut -d '|' -f 1`
    key=`echo $row | cut -d '|' -f 2`
    echo "-->'$lang' == '$key'"
    sqlite3 $initialdb "insert into system_cfg values('$lang','$key', 0, 0);"
done
rm ${initialdb}.bkp

# create active db link to initial db
if [ ! -f $activedb ]; then
	echo "Setting up active DB link"
	ln -s $initialdb $activedb
fi

# Cleanup the temporary dir/files
rm -rf $tmpdir

exit 0
